# DiBISO plot

A Python library for plotting bibliometric research data, developed at the [DiBISO](https://www.bibliotheques.universite-paris-saclay.fr/en/department-libraries-information-and-open-science-dibiso-and-its-missions).

The library contains the following submodules:

  - `biso`: plot data for the BiSO (Open-Science Report)


Homepage: https://pypi.org/project/dibisoplot/

Documentation: https://dibiso-upsaclay.github.io/dibisoplot/

Repository URL: https://github.com/dibiso-upsaclay/dibisoplot


Romain THOMAS 2025  
Department of Libraries, Information and Open Science (DiBISO)  
Université Paris-Saclay